<?php
if ( !defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * duplicate post hook.
 */
if ( !function_exists( 'ux_cb_duplicate_post_hook' ) ) {
	function ux_cb_duplicate_post_hook( $newPostID ) {
		$newPost = get_post( $newPostID );
		$content = $newPost->post_content;
		if ( $content != '' ) {
			$content = str_replace( '&nbsp;', ' ', $content );
			$content = htmlspecialchars_decode( $content );
		}

		if ( $hasModules = get_post_meta( $newPostID, 'modules', true ) ) {
			if ( $hasModules && is_array( $hasModules ) ) {
				$metaContent = '';
				if ( $getCbContent = get_post_meta( $newPostID, 'ux-cb-content', true ) ) {
					$metaContent = $getCbContent;
				}

				$moduleTargetUniqueArray = array();
				foreach ( $hasModules as $moduleUnique ) {
					$loop_post_id = ux_cb_get_the_module_post_id( $moduleUnique );
					if ( $loop_post_id ) {
						$custom_keys = get_post_custom_keys( $loop_post_id );
						$moduleTargetUnique = ux_cb_create_uq();

						$target_post_id = ux_cb_get_the_module_post_id( $moduleTargetUnique );
						if ( !$target_post_id ) {
							$post_fields = array(
								'post_title' => $moduleTargetUnique,
								'post_name' => $moduleTargetUnique,
								'post_status' => 'publish',
								'post_type' => 'ux-cb-modules'
							);

							$target_post_id = wp_insert_post( $post_fields );

							$content = str_replace( $moduleUnique, $moduleTargetUnique, $content );
							$metaContent = str_replace( $moduleUnique, $moduleTargetUnique, $metaContent );
						}

						foreach ( $custom_keys as $key ) {
							$values = get_post_meta( $loop_post_id, $key, true );
							update_post_meta( $target_post_id, $key, $values );
						}

						array_push( $moduleTargetUniqueArray, $moduleTargetUnique );
					}
				}

				$postFields = array(
					'ID' => $newPostID,
					'post_content' => $content
				);

				wp_update_post( $postFields );
				if ( count( $moduleTargetUniqueArray ) ) {
					update_post_meta( $newPostID, 'modules', $moduleTargetUniqueArray );
					update_post_meta( $newPostID, 'ux-cb-content', $metaContent );
				}
			}
		}
	}
}

/**
 * duplicate post create duplicate.
 */
if ( !function_exists( 'ux_cb_duplicate_post_dp_duplicate_page' ) ) {
	function ux_cb_duplicate_post_dp_duplicate_page( $newPostID, $post, $status ) {
		ux_cb_duplicate_post_hook( $newPostID );
	}
	add_action( 'dp_duplicate_page', 'ux_cb_duplicate_post_dp_duplicate_page', 99, 3 );
	add_action( 'dp_duplicate_post', 'ux_cb_duplicate_post_dp_duplicate_page', 99, 3 );
}

/**
 * duplicate post for icl.
 */
if ( !function_exists( 'ux_cb_icl_make_duplicate' ) ) {
	function ux_cb_icl_make_duplicate( $master_post_id, $lang, $post_array, $id ) {
		ux_cb_duplicate_post_hook( $id );

	}
	add_action( 'icl_make_duplicate', 'ux_cb_icl_make_duplicate', 99, 4 );
}

/**
 * duplicate post for polylang.
 */
if ( !function_exists( 'ux_cb_polylang_duplicate' ) ) {
	function ux_cb_polylang_duplicate() {
		if ( isset( $_GET[ 'from_post' ], $_GET[ 'new_lang' ], $_GET[ 'post_type' ] ) ) {
			global $post;
			ux_cb_duplicate_post_hook( $post->ID );
		}

	}
	add_action( 'admin_footer', 'ux_cb_polylang_duplicate', 99, 4 );
}

?>