<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * UX Content Builder Module Embed shortcode.
 */
function ux_cb_module_embed_shortcode($atts, $content=false) {
	$moduleID = 'embed';
	
	$atts = shortcode_atts( array(
		'unique' => false,
		'col' => '12',
		'width' => '12/12',
		'style' => ''
	), $atts, 'ux_cb_embed' );
	
	$html = ux_cb_get_module_template($moduleID, $atts, $content);
	return $html;
}
add_shortcode('ux_cb_embed', 'ux_cb_module_embed_shortcode');

/**
 * UX Content Builder Module Embed container.
 */
function ux_cb_module_embed_container($module, $moduleUnique) {
	$html = '';
	
	$post_id = ux_cb_get_the_module_post_id($moduleUnique);

	//source
	$source = false;
	$source = get_post_meta($post_id, '__ux_cb_module_embed_source', true );


	//cover image
	$embedHasCoverImageClass = false;
	$embedCoverImage =  false;
	$embedCoverImage = get_post_meta( $post_id, '__ux_cb_module_embed_image', true );

	//get hosted video poster image
	if ( $source == 'hostedvideo' ) {
		$embedCoverImage = get_post_meta( $post_id, '__ux_cb_module_embed_hosted_video_image', true );
	}

	//If export data-src
	$dataSrcIf = false;
	if ( $embedCoverImage &&  ( $source === 'vimeo' || $source === 'youtube' ) ) {
		$dataSrcIf = true; 
	}

	$hostedVideoSrc = 'data-src';
	if ( ! $module['is_frontend'] ) {
		$hostedVideoSrc = 'src';
	}

	//autoplay
	$autoplay = false;
	$autoplayTag = false;
	$hostedAutoplayTag = '';
	if ( $source === 'hostedvideo' ) {
		if ( 'on' === get_post_meta( $post_id, '__ux_cb_module_embed_hosted_video_autoplay', true ) ) {
			$hostedAutoplayTag = 'muted autoplay'; 
		}

	}else{
		if ( 'on' === get_post_meta( $post_id, '__ux_cb_module_embed_autoplay', true ) ) {
			if ( $source === 'vimeo' || $source === 'youtube' ) {
				$autoplay = true;
				$autoplayTag = true;
				$dataSrcIf = true;
			}
		} else {
			if ( $embedCoverImage &&  ( $source === 'vimeo' || $source === 'youtube' ) ) {
				$autoplayTag = true;
			}
		}
	}

	//hosted video buttons enable
	$showPlayBtnClass = '';
	$showMuteBtnClass = '';
	$playBtnColor = '#555';
	$muteBtnColor = '#555';

	if ( 'on' === get_post_meta( $post_id, '__ux_cb_module_embed_hosted_video_play_btn', true ) ) {
		$showPlayBtnClass = 'hostedvideo-show-playbtn';
		if ( $playBtnColorGet = get_post_meta( $post_id, '__ux_cb_module_embed_hosted_video_play_btn_color', true ) ) {
			$playBtnColor = $playBtnColorGet;
		}
	}
	if ( 'on' === get_post_meta( $post_id, '__ux_cb_module_embed_hosted_video_mute_btn', true ) ) {
		$showMuteBtnClass = 'hostedvideo-show-mutebtn';
		if ( $muteBtnColorGet = get_post_meta( $post_id, '__ux_cb_module_embed_hosted_video_mute_btn_color', true ) ) {
			$muteBtnColor = $muteBtnColorGet;
		}
	}

	//embed code
	$embedCode = false;
	$hostedvideo_mp4 = false;
	$hostedvideo_ogg = false;
	$hostedvideo_webm = false;

	switch ( $source ) {

		case 'youtube':
			$embed = get_post_meta( $post_id, '__ux_cb_module_embed_code_youtube', true );
		break;

		case 'vimeo':
			$embed = get_post_meta( $post_id, '__ux_cb_module_embed_code_vimeo', true );
		break;

		case 'hostedvideo':
			$hostedvideo_mp4 = get_post_meta($post_id, '__ux_cb_module_embed_hosted_video_mp4', true);
			$hostedvideo_ogg = get_post_meta($post_id, '__ux_cb_module_embed_hosted_video_ogg', true);
			$hostedvideo_webm = get_post_meta($post_id, '__ux_cb_module_embed_hosted_video_webm', true);
		
		default:
			$embed = get_post_meta( $post_id, '__ux_cb_module_embed_code', true );
		break;
	}

	if ( $embed ) {
		if ( ! $module['is_frontend'] ) {
			$embedCode = ux_cb_embed_html( $embed, false, false );
		} else {
			$embedCode = ux_cb_embed_html( $embed, $dataSrcIf, $autoplayTag );
		}
	}
	
	//embed ratio
	$embedRatio = get_post_meta( $post_id, '__ux_cb_module_embed_ratio', true );
	if ( ! $embedRatio ) {
		$embedRatio = 'none';
	}
	
	//embed custom ratio
	$embedCustomRatioW = get_post_meta( $post_id, '__ux_cb_module_embed_custom_ratio_w', true );
	$embedCustomRatioW = (int)$embedCustomRatioW;
	if ( !$embedCustomRatioW ) {
		$embedCustomRatioW = 0;
	}
	$embedCustomRatioH = get_post_meta( $post_id, '__ux_cb_module_embed_custom_ratio_h', true );
	$embedCustomRatioH = (int)$embedCustomRatioH;
	if ( !$embedCustomRatioH ) {
		$embedCustomRatioH = 0;
	}
	
	//embed ratio class
	$embedRatioClass = false;
	if ( $embedRatio != 'none' ) {
		$embedRatioClass = 'embed-wrap-with-radio';
	}
	
	//cover image export
	$embedCoverImageAlt = get_the_title($module['postID']);
	$thumbBlank = 'data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7';
	$hostedVideoPoster = '';
	if ( $embedCoverImage ) {
		if ( $embedCoverImage != ''){
			$embedCoverImagSrc = wp_get_attachment_image_src($embedCoverImage, 'full');
			$embedCoverImageUrl = $embedCoverImagSrc[0]; 
			$embedCoverImageSrc = $thumbBlank;
			if ( ! $module['is_frontend'] ) {
				$embedCoverImageSrc = esc_url( $embedCoverImageUrl );
			}
			$embedCoverImageAlt = get_the_title($embedCoverImage);
			$htmlDataSrcset = false;
			$htmlDataSizes = false;
			
			if ( ! ux_cb_disable_image_srcset() ) {
				$embedCoverImageSrcset = wp_get_attachment_image_srcset($embedCoverImage, 'full');
				$embedCoverImageSizes = wp_get_attachment_image_sizes($embedCoverImage, 'full');
				
				$htmlDataSrcset = 'data-srcset="'. wp_kses_post( $embedCoverImageSrcset ). '"';
				$htmlDataSizes = 'data-sizes="'. wp_kses_post( $embedCoverImageSizes ). '"';
			}
			
			$embedCoverImage = '<div class="embed-video-cover"><img class="embed-video-cover-img lazy" src="'.esc_attr($embedCoverImageSrc).'" data-src="'.esc_url($embedCoverImageUrl).'" alt="'.esc_attr($embedCoverImageAlt).'" ' .$htmlDataSrcset. ' ' .$htmlDataSizes. '><span class="fa fa-play video-play-btn"></span></div>';
			$embedHasCoverImageClass = 'embed-wrap-has-cover'; 
			$hostedVideoPoster = $embedCoverImageUrl;
		}
	}

	//padding bottom
	$paddingBottom = false;
	if ( $embedRatio != 'none'){
		switch($embedRatio){
			case '16_9':
				$paddingBottom = 'padding-bottom:' .(9/16) * 100 .'%;';
			break;
			case '4_3':
				$paddingBottom = 'padding-bottom:' .(3/4) * 100 .'%;';
			break;
			case 'custom':
				if( $embedCustomRatioW  > 0 &&  $embedCustomRatioH  > 0){
					$paddingBottom = 'padding-bottom: ' . (esc_attr( $embedCustomRatioH ) / esc_attr( $embedCustomRatioW )) * 100 . '%;';
				}
			break;
		}
	}
	
	//animation
	$animationClass = ux_cb_module_field_animation_class($module);
	$animationEnd = ux_cb_module_field_animation_end($module);

	//style
	if ( ! $module['is_frontend'] ) {
		$html .= '<style type="text/css">' . sanitize_text_field( ux_cb_module_embed_style( $post_id, $moduleUnique, $html ) ). '</style>';
	}
	
	$html .= '<div class="embed-wrap ' .sanitize_html_class($embedRatioClass). ' ' .sanitize_html_class($embedHasCoverImageClass). ' ' .esc_attr($animationClass). '" style="' .esc_attr($paddingBottom). '" data-animationend="' .esc_attr($animationEnd). '">';
	if ( $source == 'hostedvideo' ) {
		$html .= '<div class="embed-hostedvideo-wrap '.sanitize_html_class( $showPlayBtnClass ).' '.sanitize_html_class( $showMuteBtnClass ).'" style="' .esc_attr( $paddingBottom ). '">';
		$html .= '<video class="embed-hostedvideo lazy" poster="'.esc_url( $hostedVideoPoster ).'" playsinline loop '.esc_attr( $hostedAutoplayTag ).'>';
			if($hostedvideo_mp4) {
				$html .= '<source '.esc_attr($hostedVideoSrc).'="'.esc_url($hostedvideo_mp4).'" type="video/mp4">';
			}
			if($hostedvideo_ogg) {
				$html .= '<source '.esc_attr($hostedVideoSrc).'="'.esc_url($hostedvideo_ogg).'" type="video/ogg">';
			}
			if($hostedvideo_webm) {
				$html .= '<source '.esc_attr($hostedVideoSrc).'="'.esc_url($hostedvideo_webm).'" type="video/webm">';
			}
		$html .= '</video>';
		$html .= '<div class="hostedvideo-plays-btn"><svg fill="'.esc_attr( $playBtnColor ).'" class="hostedvideo-svg-play" height="48" viewBox="0 0 48 48" width="48" xmlns="http://www.w3.org/2000/svg"><path d="M-838-2232H562v3600H-838z" fill="none"></path><path d="M16 10v28l22-14z"></path><path d="M0 0h48v48H0z" fill="none"></path></svg><svg fill="'.esc_attr( $playBtnColor ).'" class="hostedvideo-svg-pause" height="48" viewBox="0 0 48 48" width="48" xmlns="http://www.w3.org/2000/svg"><path d="M12 38h8V10h-8v28zm16-28v28h8V10h-8z"></path><path d="M0 0h48v48H0z" fill="none"></path></svg></div>';
		$html .= '<div class="hostedvideo-mute-btn"><svg fill="'.esc_attr( $muteBtnColor ).'" class="hostedvideo-svg-mute" height="48" version="1.1" viewBox="0 0 48 48" width="48" xml:space="preserve" xmlns="http://www.w3.org/2000/svg"><path d="M23.727 16.403v24.134a8.296 8.296 0 0 0-4.35-1.233c-4.612 0-8.353 3.74-8.353 8.349a8.354 8.354 0 0 0 8.353 8.354c4.61 0 8.349-3.739 8.35-8.352V25.151l21.25-6.109V33.33a8.296 8.296 0 0 0-4.35-1.233c-4.614 0-8.353 3.739-8.353 8.348a8.354 8.354 0 0 0 8.353 8.354c4.344 0 7.914-3.325 8.31-7.57h.04V7.993l-29.25 8.41z"></path></svg></div>';
		$html .= '</div>'; 

	} else {
		if ( ! $autoplay ) {
			$html .= $embedCoverImage;
		}
		$html .= wp_kses( balanceTags( $embedCode, true ), ux_cb_kses_allowed_html() );
	}
	
	$html .= '</div>';
	
	return $html;
}

add_filter( 'ux_cb_module_container_embed', 'ux_cb_module_embed_container', 10, 2 );

?>